@@ -3,7 +3,7 @@ from holowan.HoloWAN import SubHoloWAN
 # from holowan.HoloWAN import HoloWAN
 import json
 import os
-from utils import MyUtil as mt
+from holowan.myUtils import MyUtil as mt
 
 HoloWANIP = "192.168.1.223"
 HoloWANPort = "8080"
